# linregmc package  (Linear regression with Monte Carlo error analysis)

This package is a single module which contains four functions:<br>
addnoise        - introduce noise in the data based on known experimental precision<br>
linreg          - perform multiple linear regressions and calculate goodness-of-fit<br>
confidence      - get confidence intervals, plot distributions etc.<br>
linconf         - do all the steps in succession, including possible transformation of the data<br>
